@@ -8,13 +8,14 @@ PYTHON_CLIENT_ID = "beneath-python"
 DEFAULT_READ_BATCH_SIZE = 1000
 DEFAULT_READ_ALL_MAX_BYTES = 10 * 2 ** 20
 DEFAULT_WRITE_DELAY_MS = 1000
-DEFAULT_WRITE_PIPELINE_CHECKPOINT_DELAY_MS = 30000
+DEFAULT_CHECKPOINT_COMMIT_DELAY_MS = 30000
 DEFAULT_SUBSCRIBE_POLL_AT_LEAST_EVERY_MS = 60000
 DEFAULT_SUBSCRIBE_POLL_AT_MOST_EVERY_MS = 1000
 DEFAULT_QUERY_WAREHOUSE_TIMEOUT_MS = 60 * 1000
 DEFAULT_QUERY_WAREHOUSE_MAX_BYTES_SCANNED = 10000000000
-MAX_WRITE_SIZE_BYTES = 10000000
-MAX_WRITE_SIZE_COUNT = 10000
+MAX_RECORD_SIZE_BYTES = 8192
+MAX_BATCH_SIZE_BYTES = 10000000
+MAX_BATCH_SIZE_COUNT = 10000
 
 if DEV:
     BENEATH_FRONTEND_HOST = "http://localhost:3000"
