@@ -14,7 +14,7 @@ def parse_pipeline_args():
     parser.add_argument(
         "service_path",
         type=str,
-        help="path for the pipeline ('username/project/name')",
+        help="project and path for the pipeline's service and state ('username/project/name')",
     )
     parser.add_argument(
         "--strategy",
@@ -32,13 +32,19 @@ def parse_pipeline_args():
         "--read-quota-mb",
         type=mb_to_bytes,
         default=None,
-        help="sets a limit on the pipeline's monthly read quota (set to 0 for unlimited quota)",
+        help="limit on the pipeline's service's monthly read quota (set to 0 for unlimited quota)",
     )
     parser.add_argument(
         "--write-quota-mb",
         type=mb_to_bytes,
         default=None,
-        help="sets a limit on the pipeline's monthly read quota (set to 0 for unlimited quota)",
+        help="limit on the pipeline's service's monthly write quota (set to 0 for unlimited quota)",
+    )
+    parser.add_argument(
+        "--scan-quota-mb",
+        type=mb_to_bytes,
+        default=None,
+        help="limit on the pipeline's service's monthly scan quota (set to 0 for unlimited quota)",
     )
 
     args = parser.parse_args()
@@ -52,3 +58,5 @@ def parse_pipeline_args():
         os.environ["BENEATH_PIPELINE_SERVICE_READ_QUOTA"] = str(args.read_quota_mb)
     if args.write_quota_mb is not None:
         os.environ["BENEATH_PIPELINE_SERVICE_WRITE_QUOTA"] = str(args.write_quota_mb)
+    if args.scan_quota_mb is not None:
+        os.environ["BENEATH_PIPELINE_SERVICE_SCAN_QUOTA"] = str(args.scan_quota_mb)
